/*
 * Copyright 2011 Hanson Robokind LLC.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/*
 * TTSPanel.java
 *
 * Created on Jul 28, 2011, 12:47:36 AM
 */
package org.rwshop.swing.speech;

import org.robokind.api.speech.SpeechService;

/**
 *
 * @author Matthew Stevenson <www.robokind.org>
 */
public class TTSPanel extends javax.swing.JPanel {
    private SpeechService myTTSEngine;
    /** Creates new form TTSPanel */
    public TTSPanel() {
        initComponents();
    }
    
    public void setTTSEngine(SpeechService engine){
        myTTSEngine = engine;
    }
    
    private void speak(String txt){
        if(myTTSEngine == null){
            return;
        }
        myTTSEngine.speak(txt);
    }

    /** This method is called from within the constructor to
     * initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is
     * always regenerated by the Form Editor.
     */
    @SuppressWarnings("unchecked")
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {

        btnSpeakAll = new javax.swing.JButton();
        btnSpeakSelected = new javax.swing.JButton();
        jScrollPane1 = new javax.swing.JScrollPane();
        txtSpeech = new javax.swing.JTextArea();
        btnCancelSpeech = new javax.swing.JButton();

        btnSpeakAll.setText("Speak All");
        btnSpeakAll.setMaximumSize(new java.awt.Dimension(120, 30));
        btnSpeakAll.setMinimumSize(new java.awt.Dimension(120, 30));
        btnSpeakAll.setPreferredSize(new java.awt.Dimension(120, 30));
        btnSpeakAll.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                btnSpeakAllActionPerformed(evt);
            }
        });

        btnSpeakSelected.setText("Speak Selected");
        btnSpeakSelected.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                btnSpeakSelectedActionPerformed(evt);
            }
        });

        txtSpeech.setColumns(20);
        txtSpeech.setRows(5);
        jScrollPane1.setViewportView(txtSpeech);

        btnCancelSpeech.setText("Cancel Speech");
        btnCancelSpeech.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                btnCancelSpeechActionPerformed(evt);
            }
        });

        javax.swing.GroupLayout layout = new javax.swing.GroupLayout(this);
        this.setLayout(layout);
        layout.setHorizontalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(layout.createSequentialGroup()
                .addComponent(btnSpeakAll, javax.swing.GroupLayout.PREFERRED_SIZE, 120, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(btnSpeakSelected, javax.swing.GroupLayout.PREFERRED_SIZE, 120, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(btnCancelSpeech)
                .addGap(38, 38, 38))
            .addComponent(jScrollPane1, javax.swing.GroupLayout.DEFAULT_SIZE, 405, Short.MAX_VALUE)
        );
        layout.setVerticalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, layout.createSequentialGroup()
                .addComponent(jScrollPane1, javax.swing.GroupLayout.DEFAULT_SIZE, 95, Short.MAX_VALUE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(btnSpeakAll, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addComponent(btnSpeakSelected, javax.swing.GroupLayout.PREFERRED_SIZE, 30, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addComponent(btnCancelSpeech)))
        );
    }// </editor-fold>//GEN-END:initComponents

    private void btnSpeakAllActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_btnSpeakAllActionPerformed
        String txt = txtSpeech.getText();
        speak(txt);
    }//GEN-LAST:event_btnSpeakAllActionPerformed

    private void btnSpeakSelectedActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_btnSpeakSelectedActionPerformed
        String txt = txtSpeech.getSelectedText();
        if(txt == null || txt.isEmpty()){
            txt = txtSpeech.getText();
        }
        speak(txt);
    }//GEN-LAST:event_btnSpeakSelectedActionPerformed

    private void btnCancelSpeechActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_btnCancelSpeechActionPerformed
        if(myTTSEngine == null){
            return;
        }
        myTTSEngine.cancelSpeech();
    }//GEN-LAST:event_btnCancelSpeechActionPerformed

    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JButton btnCancelSpeech;
    private javax.swing.JButton btnSpeakAll;
    private javax.swing.JButton btnSpeakSelected;
    private javax.swing.JScrollPane jScrollPane1;
    private javax.swing.JTextArea txtSpeech;
    // End of variables declaration//GEN-END:variables
}
